.. list-table:: Variables In ERDDAP
   :header-rows: 1

   * - netcdf varname
     - Units
     - In ERDDAP
   * - ``expocode``
     - None
     - :bdg-success:`yes`
   * - ``section_id``
     - None
     - :bdg-success:`yes`
   * - ``line_id``
     - None
     - :bdg-success:`yes`
   * - ``station``
     - None
     - :bdg-success:`yes`
   * - ``cast``
     - None
     - :bdg-success:`yes`
   * - ``bios_castid``
     - None
     - :bdg-danger:`no`
   * - ``sample``
     - None
     - :bdg-success:`yes`
   * - ``geotraces_event``
     - None
     - :bdg-danger:`no`
   * - ``geotraces_sample``
     - None
     - :bdg-danger:`no`
   * - ``bionbr``
     - None
     - :bdg-danger:`no`
   * - ``event_number``
     - None
     - :bdg-danger:`no`
   * - ``bottle_number``
     - None
     - :bdg-success:`yes`
   * - ``date``
     - None
     - :bdg-success:`yes`
   * - ``time``
     - None
     - :bdg-success:`yes`
   * - ``latitude``
     - None
     - :bdg-success:`yes`
   * - ``longitude``
     - None
     - :bdg-success:`yes`
   * - ``btm_depth``
     - meters
     - :bdg-success:`yes`
   * - ``pressure``
     - dbar
     - :bdg-success:`yes`
   * - ``ctd_pressure_raw``
     - dbar
     - :bdg-danger:`no`
   * - ``ctd_temperature_unk``
     - degC
     - :bdg-success:`yes`
   * - ``ctd_temperature_68``
     - degC
     - :bdg-success:`yes`
   * - ``ctd_temperature``
     - degC
     - :bdg-success:`yes`
   * - ``ctd_salinity``
     - 1
     - :bdg-success:`yes`
   * - ``ctd_absolute_salinity``
     - g/kg
     - :bdg-danger:`no`
   * - ``ctd_conservative_temperature``
     - degC
     - :bdg-danger:`no`
   * - ``bottle_salinity``
     - 1
     - :bdg-success:`yes`
   * - ``density_salinity``
     - g/kg
     - :bdg-danger:`no`
   * - ``density_salinity2``
     - g/kg
     - :bdg-danger:`no`
   * - ``refractive_index_anomaly``
     - 1
     - :bdg-danger:`no`
   * - ``density_salinity_practical_salinity``
     - 1
     - :bdg-danger:`no`
   * - ``density_salinity_practical_salinity2``
     - 1
     - :bdg-danger:`no`
   * - ``ctd_sound_velocity_salinity``
     - g/kg
     - :bdg-danger:`no`
   * - ``ctd_oxygen_ml_l``
     - ml/l
     - :bdg-success:`yes`
   * - ``ctd_oxygen``
     - umol/kg
     - :bdg-success:`yes`
   * - ``ctd_oxygen_umol_l``
     - umol l-1
     - :bdg-success:`yes`
   * - ``ctd_optode_oxygen``
     - umol/kg
     - :bdg-danger:`no`
   * - ``ctd_optode_oxygen_raw``
     - volts
     - :bdg-danger:`no`
   * - ``oxygen_ml_l``
     - ml/l
     - :bdg-success:`yes`
   * - ``oxygen``
     - umol/kg
     - :bdg-success:`yes`
   * - ``silicate``
     - umol/kg
     - :bdg-success:`yes`
   * - ``silicate_l``
     - umol l-1
     - :bdg-success:`yes`
   * - ``ammonium``
     - umol/kg
     - :bdg-success:`yes`
   * - ``nitrate``
     - umol/kg
     - :bdg-success:`yes`
   * - ``ctd_nitrate``
     - umol/kg
     - :bdg-danger:`no`
   * - ``nitrite``
     - umol/kg
     - :bdg-success:`yes`
   * - ``phosphate``
     - umol/kg
     - :bdg-success:`yes`
   * - ``phosphate_l``
     - umol l-1
     - :bdg-success:`yes`
   * - ``nitrite_nitrate``
     - umol/kg
     - :bdg-success:`yes`
   * - ``nitrite_nitrate_l``
     - umol l-1
     - :bdg-success:`yes`
   * - ``cfc_11``
     - pmol/kg
     - :bdg-success:`yes`
   * - ``cfc_11_l``
     - pmol/l
     - :bdg-success:`yes`
   * - ``cfc_12``
     - pmol/kg
     - :bdg-success:`yes`
   * - ``cfc_12_l``
     - pmol/l
     - :bdg-success:`yes`
   * - ``cfc_113``
     - pmol/kg
     - :bdg-success:`yes`
   * - ``cfc_113_``
     - pmol/l
     - :bdg-success:`yes`
   * - ``dichlorofluoroethane``
     - pmol/kg
     - :bdg-danger:`no`
   * - ``chlorodifluoroethane``
     - pmol/kg
     - :bdg-danger:`no`
   * - ``chlorodifluoromethane``
     - pmol/kg
     - :bdg-danger:`no`
   * - ``sulfur_hexifluoride``
     - fmol/kg
     - :bdg-success:`yes`
   * - ``sulfur_hexifluoride_l``
     - fmol/l
     - :bdg-success:`yes`
   * - ``total_carbon``
     - umol/kg
     - :bdg-success:`yes`
   * - ``total_alkalinity``
     - umol/kg
     - :bdg-success:`yes`
   * - ``fco2``
     - uatm
     - :bdg-success:`yes`
   * - ``fco2_in_situ``
     - uatm
     - :bdg-danger:`no`
   * - ``fco2_temperature``
     - degC
     - :bdg-success:`yes`
   * - ``partial_pressure_of_co2``
     - uatm
     - :bdg-success:`yes`
   * - ``co2_mole_fraction``
     - 1e-6
     - :bdg-danger:`no`
   * - ``partial_co2_temperature``
     - degC
     - :bdg-success:`yes`
   * - ``ph_total_h_scale``
     - None
     - :bdg-success:`yes`
   * - ``ph_unknown_scale``
     - None
     - :bdg-success:`yes`
   * - ``ph_nbs``
     - None
     - :bdg-danger:`no`
   * - ``ph_sws``
     - None
     - :bdg-success:`yes`
   * - ``ph_temperature``
     - degC
     - :bdg-success:`yes`
   * - ``dissolved_organic_carbon``
     - umol/kg
     - :bdg-success:`yes`
   * - ``fdom``
     - 1
     - :bdg-danger:`no`
   * - ``dissolved_organic_carbon_nasa``
     - umol l-1
     - :bdg-danger:`no`
   * - ``tritium_activity``
     - kBq m-3
     - :bdg-success:`yes`
   * - ``tritium``
     - 1e-18
     - :bdg-success:`yes`
   * - ``helium``
     - nmol/kg
     - :bdg-success:`yes`
   * - ``helium_l``
     - nmol/l
     - :bdg-success:`yes`
   * - ``delta_helium_3``
     - percent
     - :bdg-success:`yes`
   * - ``ref_temperature_c``
     - degC
     - :bdg-success:`yes`
   * - ``ref_temperature``
     - degC
     - :bdg-success:`yes`
   * - ``rev_pressure``
     - dbar
     - :bdg-success:`yes`
   * - ``rev_temperature_c``
     - degC
     - :bdg-success:`yes`
   * - ``rev_temperature``
     - degC
     - :bdg-success:`yes`
   * - ``rev_temperature_90``
     - degC
     - :bdg-success:`yes`
   * - ``del_carbon_13_dic``
     - 1e-3
     - :bdg-success:`yes`
   * - ``del_carbon_14_dic``
     - 1e-3
     - :bdg-success:`yes`
   * - ``dissolved_organic_nitrogen``
     - umol/kg
     - :bdg-success:`yes`
   * - ``total_organic_carbon``
     - umol/kg
     - :bdg-success:`yes`
   * - ``total_organic_carbon_l``
     - umol l-1
     - :bdg-success:`yes`
   * - ``particulate_organic_carbon``
     - ug/kg
     - :bdg-success:`yes`
   * - ``particulate_organic_carbon_l``
     - ug/l
     - :bdg-success:`yes`
   * - ``d13c_poc``
     - 1e-3
     - :bdg-danger:`no`
   * - ``particulate_organic_nitrogen``
     - ug/kg
     - :bdg-success:`yes`
   * - ``particulate_organic_nitrogen_l``
     - ug/l
     - :bdg-success:`yes`
   * - ``particulate_organic_nitrogen_mol``
     - umol l-1
     - :bdg-success:`yes`
   * - ``particulate_organic_phosphorus_l``
     - ug/l
     - :bdg-danger:`no`
   * - ``particulate_organic_phosphorus``
     - umol l-1
     - :bdg-danger:`no`
   * - ``particulate_chemical_oxygen_demand_l``
     - ug/l
     - :bdg-danger:`no`
   * - ``dissolved_organic_phosphorus``
     - umol/kg
     - :bdg-danger:`no`
   * - ``total_dissolved_phosphorus``
     - umol/kg
     - :bdg-danger:`no`
   * - ``total_dissolved_phosphorus_l``
     - umol l-1
     - :bdg-danger:`no`
   * - ``dissolved_atp``
     - pmol/l
     - :bdg-danger:`no`
   * - ``particulate_atp``
     - pmol/l
     - :bdg-danger:`no`
   * - ``total_dissolved_nitrogen``
     - umol/kg
     - :bdg-success:`yes`
   * - ``total_organic_nitrogen``
     - umol/kg
     - :bdg-danger:`no`
   * - ``total_organic_nitrogen_l``
     - umol l-1
     - :bdg-danger:`no`
   * - ``neon``
     - nmol/kg
     - :bdg-danger:`no`
   * - ``neon_l``
     - nmol/l
     - :bdg-danger:`no`
   * - ``del_oxygen_18``
     - 1e-3
     - :bdg-success:`yes`
   * - ``del_oxygen_17``
     - 1e-3
     - :bdg-danger:`no`
   * - ``del_deuterium``
     - 1e-3
     - :bdg-danger:`no`
   * - ``delsi30``
     - 1e-3
     - :bdg-danger:`no`
   * - ``del_nitrogen_15``
     - 1e-3
     - :bdg-danger:`no`
   * - ``carbon_tetrachloride``
     - pmol/kg
     - :bdg-success:`yes`
   * - ``carbon_tetrachloride_l``
     - pmol/l
     - :bdg-success:`yes`
   * - ``nickel``
     - umol l-1
     - :bdg-danger:`no`
   * - ``dissolved_aluminum``
     - nmol/l
     - :bdg-danger:`no`
   * - ``barium``
     - nmol/kg
     - :bdg-success:`yes`
   * - ``barium_l``
     - nmol/l
     - :bdg-success:`yes`
   * - ``copper``
     - umol l-1
     - :bdg-danger:`no`
   * - ``iron``
     - nmol/l
     - :bdg-danger:`no`
   * - ``manganese``
     - nmol/l
     - :bdg-danger:`no`
   * - ``ctd_fluor``
     - mg/m^3
     - :bdg-success:`yes`
   * - ``ctd_fluor_arbitrary``
     - None
     - :bdg-success:`yes`
   * - ``ctd_fluor_raw``
     - volts
     - :bdg-success:`yes`
   * - ``par``
     - umol m-2 s-1
     - :bdg-success:`yes`
   * - ``par_raw``
     - volts
     - :bdg-success:`yes`
   * - ``cdom300``
     - m^-1
     - :bdg-success:`yes`
   * - ``cdom325``
     - m^-1
     - :bdg-success:`yes`
   * - ``cdom340``
     - m^-1
     - :bdg-success:`yes`
   * - ``cdom380``
     - m^-1
     - :bdg-success:`yes`
   * - ``cdom412``
     - m^-1
     - :bdg-success:`yes`
   * - ``cdom443``
     - m^-1
     - :bdg-success:`yes`
   * - ``cdom490``
     - m^-1
     - :bdg-success:`yes`
   * - ``cdom555``
     - m^-1
     - :bdg-success:`yes`
   * - ``spar_raw``
     - volts
     - :bdg-danger:`no`
   * - ``cdom2c``
     - None
     - :bdg-danger:`no`
   * - ``cdom3c``
     - None
     - :bdg-danger:`no`
   * - ``cdomsl``
     - 1/nm
     - :bdg-success:`yes`
   * - ``cdomsn``
     - 1/nm
     - :bdg-success:`yes`
   * - ``iodine_129``
     - Bq m-3
     - :bdg-danger:`no`
   * - ``plutonium``
     - mBq m-3
     - :bdg-danger:`no`
   * - ``radium_226``
     - 0.000166 Bq/kg
     - :bdg-success:`yes`
   * - ``radium_228``
     - 0.000166 Bq/kg
     - :bdg-success:`yes`
   * - ``ctd_transmissometer``
     - 1e-2
     - :bdg-success:`yes`
   * - ``ctd_transmissometer_raw``
     - volts
     - :bdg-success:`yes`
   * - ``ctd_beamcp``
     - m^-1
     - :bdg-success:`yes`
   * - ``beamap``
     - m^-1
     - :bdg-danger:`no`
   * - ``ctd_beta700``
     - m-1 sr-1
     - :bdg-success:`yes`
   * - ``ctd_beta700_raw``
     - volts
     - :bdg-success:`yes`
   * - ``ctd_bbp700``
     - m^-1
     - :bdg-success:`yes`
   * - ``ctd_turbidity_ftu``
     - 1
     - :bdg-success:`yes`
   * - ``ctd_turbidity_ntu``
     - 1
     - :bdg-success:`yes`
   * - ``ctd_cdom``
     - 1
     - :bdg-success:`yes`
   * - ``ctd_cdom_raw``
     - volts
     - :bdg-success:`yes`
   * - ``argon_39``
     - 1e-2
     - :bdg-danger:`no`
   * - ``cesium_137_bq``
     - Bq m-3
     - :bdg-danger:`no`
   * - ``cesium_137``
     - 0.000166 Bq/kg
     - :bdg-danger:`no`
   * - ``cesium_137_bq_kg``
     - mBq kg-1
     - :bdg-danger:`no`
   * - ``cesium_134_bq``
     - Bq m-3
     - :bdg-danger:`no`
   * - ``cesium_134_bq_kg``
     - mBq kg-1
     - :bdg-danger:`no`
   * - ``krypton_85``
     - 0.0000166 Bq/kg
     - :bdg-danger:`no`
   * - ``strontium_90``
     - 0.000166 Bq/kg
     - :bdg-danger:`no`
   * - ``nitrous_oxide``
     - nmol/kg
     - :bdg-success:`yes`
   * - ``radium_228_226``
     - None
     - :bdg-danger:`no`
   * - ``quality_word_one``
     - None
     - :bdg-danger:`no`
   * - ``quality_word_two``
     - None
     - :bdg-danger:`no`
   * - ``methyl_chloroform``
     - pmol/kg
     - :bdg-danger:`no`
   * - ``iodate``
     - nmol/kg
     - :bdg-danger:`no`
   * - ``iodide``
     - nmol/kg
     - :bdg-danger:`no`
   * - ``chlorophyll_a_ug_kg``
     - ug/kg
     - :bdg-success:`yes`
   * - ``chlorophyll_a``
     - ug/l
     - :bdg-success:`yes`
   * - ``phaeophytin``
     - ug/kg
     - :bdg-success:`yes`
   * - ``phaeophytin_ug_l``
     - ug/l
     - :bdg-success:`yes`
   * - ``methyl_chloride``
     - pmol/kg
     - :bdg-danger:`no`
   * - ``methane``
     - nmol/kg
     - :bdg-danger:`no`
   * - ``methane_l``
     - nmol/l
     - :bdg-danger:`no`
   * - ``dimethyl_sulfide``
     - nmol/l
     - :bdg-danger:`no`
   * - ``nitrogen``
     - umol/kg
     - :bdg-danger:`no`
   * - ``calcium``
     - mmol kg-1
     - :bdg-danger:`no`
   * - ``argon``
     - umol/kg
     - :bdg-success:`yes`
   * - ``argon_l``
     - umol l-1
     - :bdg-success:`yes`
   * - ``dissolved_organic_carbon_14``
     - 1e-3
     - :bdg-danger:`no`
   * - ``dissolved_organic_carbon_13``
     - 1e-3
     - :bdg-danger:`no`
   * - ``d15n_no3``
     - 1e-3
     - :bdg-success:`yes`
   * - ``d15n_no2``
     - 1e-3
     - :bdg-danger:`no`
   * - ``d15n_nh4``
     - 1e-3
     - :bdg-danger:`no`
   * - ``d15n_n2o``
     - 1e-3
     - :bdg-danger:`no`
   * - ``d15n_nitrite_nitrate``
     - 1e-3
     - :bdg-success:`yes`
   * - ``d15n_pon``
     - 1e-3
     - :bdg-danger:`no`
   * - ``d18o_nitrite_nitrate``
     - 1e-3
     - :bdg-success:`yes`
   * - ``d18o_nitrate``
     - 1e-3
     - :bdg-success:`yes`
   * - ``d18o_nitrite``
     - 1e-3
     - :bdg-danger:`no`
   * - ``d18o_nitrust_oxide``
     - 1e-3
     - :bdg-danger:`no`
   * - ``urea``
     - umol/kg
     - :bdg-danger:`no`
   * - ``hplc_tot_chl_a``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_tot_chl_b``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_tot_chl_c``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_alpha_beta_carotenes``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_19butanoyloxyfucoxanthin``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_19_hexanoyloxyfucoxanthin``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_alloxanthin``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hpld_antheraxanthin``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_diadinoxanthin``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_diatoxanthin``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_fucoxanthin``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_peridinin``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_zeaxanthin``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_monovinyl_chlorophyll_a``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_divinyl_chlorophyll_a``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_chlorophyllide_a``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_monovinyl_chlorophyll_b``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_divinyl_chlorophyll_b``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_chlorophyll_c1_c2``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_chlorophyll_c2``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_chlorophyll_c3``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_lutein``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_neoxanthin``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_violaxanthin``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_pheophytin_a``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_pheophorbide_a``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_prasinoxanthin``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``hplc_gyroxanthin_diester``
     - mg/m^3
     - :bdg-danger:`no`
   * - ``bottle_date``
     - None
     - :bdg-danger:`no`
   * - ``bottle_time``
     - None
     - :bdg-danger:`no`
   * - ``package_depth``
     - meters
     - :bdg-danger:`no`
   * - ``odf_pressure``
     - dbar
     - :bdg-danger:`no`
   * - ``bottle_latitude``
     - None
     - :bdg-danger:`no`
   * - ``bottle_longitude``
     - None
     - :bdg-danger:`no`
   * - ``ctd_number_of_observations``
     - None
     - :bdg-danger:`no`
   * - ``ctd_elapsed_time``
     - seconds
     - :bdg-danger:`no`
   * - ``instrument_id``
     - None
     - :bdg-danger:`no`
   * - ``ctd_sampling_rate``
     - 1/s
     - :bdg-danger:`no`
   * - ``potential_temperature_c``
     - degC
     - :bdg-danger:`no`
   * - ``potential_temperature_68``
     - degC
     - :bdg-danger:`no`
   * - ``potential_temperature``
     - degC
     - :bdg-danger:`no`
   * - ``apparent_oxygen_utilization``
     - umol/kg
     - :bdg-danger:`no`
   * - ``arabinose``
     - nmol/kg
     - :bdg-danger:`no`
   * - ``bacterial_cell_count``
     - 1e8 l-1
     - :bdg-danger:`no`
   * - ``cellcount``
     - l-1
     - :bdg-danger:`no`
   * - ``synechococcus_cell_count``
     - 1e6 l-1
     - :bdg-danger:`no`
   * - ``picoeukaryote_cell_counts``
     - 1e6 l-1
     - :bdg-danger:`no`
   * - ``prochlorophyte_cell_count``
     - 1e7 l-1
     - :bdg-danger:`no`
   * - ``black_carbon``
     - umol l-1
     - :bdg-danger:`no`
   * - ``brdu_uptake``
     - pmol l-1 h-1
     - :bdg-danger:`no`
   * - ``methyl_bromide``
     - pmol/kg
     - :bdg-danger:`no`
   * - ``methyl_iodide``
     - pmol/kg
     - :bdg-danger:`no`
   * - ``dcns``
     - nmol/kg
     - :bdg-danger:`no`
   * - ``fucose``
     - nmol/kg
     - :bdg-danger:`no`
   * - ``galactose``
     - nmol/kg
     - :bdg-danger:`no`
   * - ``glucose``
     - nmol/kg
     - :bdg-danger:`no`
   * - ``mannose``
     - nmol/kg
     - :bdg-danger:`no`
   * - ``rhamnose``
     - nmol/kg
     - :bdg-danger:`no`
   * - ``density``
     - kg m-3
     - :bdg-danger:`no`
   * - ``krypton``
     - nmol/kg
     - :bdg-success:`yes`
   * - ``krypton_l``
     - nmol/l
     - :bdg-success:`yes`
   * - ``xenon``
     - nmol/kg
     - :bdg-success:`yes`
   * - ``xenon_l``
     - nmol/l
     - :bdg-success:`yes`
   * - ``pigments``
     - None
     - :bdg-danger:`no`
   * - ``reference_salinity``
     - g/kg
     - :bdg-danger:`no`
   * - ``trifluoromethylsulfur_pentafluoride``
     - fmol/kg
     - :bdg-danger:`no`
   * - ``trifluoromethylsulfur_pentafluoride_l``
     - fmol/l
     - :bdg-danger:`no`
   * - ``downcast_pressure``
     - dbar
     - :bdg-danger:`no`
   * - ``downcast_oxygen``
     - umol/kg
     - :bdg-danger:`no`
   * - ``sigma0``
     - kg m-3
     - :bdg-danger:`no`
   * - ``somma_salinity``
     - 1
     - :bdg-danger:`no`
   * - ``hplc_placeholder``
     - None
     - :bdg-danger:`no`
   * - ``dna_placeholder``
     - None
     - :bdg-danger:`no`
   * - ``update_placeholder``
     - None
     - :bdg-danger:`no`
   * - ``flow_cytometry_placeholder``
     - None
     - :bdg-danger:`no`
   * - ``abundance_placeholder``
     - None
     - :bdg-danger:`no`
   * - ``stable_isotope_probing_placeholder``
     - None
     - :bdg-danger:`no`
   * - ``quota_placeholder``
     - None
     - :bdg-danger:`no`
   * - ``image_placeholder``
     - None
     - :bdg-danger:`no`
   * - ``viral_abundance_placeholder``
     - None
     - :bdg-danger:`no`
   * - ``cdom_nasa_placeholder``
     - None
     - :bdg-danger:`no`
   * - ``cdom_ucsb_placeholder``
     - None
     - :bdg-danger:`no`
   * - ``microgel_abundance``
     - 1e6 l-1
     - :bdg-danger:`no`
   * - ``n2_argon_ratio``
     - None
     - :bdg-danger:`no`
   * - ``n2_argon_ratio_unstripped``
     - None
     - :bdg-danger:`no`
   * - ``d15n_n2``
     - 1e-3
     - :bdg-danger:`no`
   * - ``o2_ar``
     - None
     - :bdg-danger:`no`
   * - ``sm_depth``
     - meters
     - :bdg-danger:`no`
   * - ``fm_depth``
     - meters
     - :bdg-danger:`no`
   * - ``cyanobacteria_cell_count``
     - ml-1
     - :bdg-danger:`no`
   * - ``phytoplankton_cell_count``
     - ml-1
     - :bdg-danger:`no`
   * - ``he3_he4_ratio``
     - None
     - :bdg-danger:`no`
   * - ``nd_143_d_epsilon_bottle``
     - 1e4
     - :bdg-danger:`no`
   * - ``la_d_conc_bottle``
     - pmol/l
     - :bdg-danger:`no`
   * - ``ce_d_conc_bottle``
     - pmol/l
     - :bdg-danger:`no`
   * - ``pr_d_conc_bottle``
     - pmol/l
     - :bdg-danger:`no`
   * - ``sm_d_conc_bottle``
     - pmol/l
     - :bdg-danger:`no`
   * - ``eu_d_conc_bottle``
     - pmol/l
     - :bdg-danger:`no`
   * - ``gd_d_conc_bottle``
     - pmol/l
     - :bdg-danger:`no`
   * - ``tb_d_conc_bottle``
     - pmol/l
     - :bdg-danger:`no`
   * - ``dy_d_conc_bottle``
     - pmol/l
     - :bdg-danger:`no`
   * - ``ho_d_conc_bottle``
     - pmol/l
     - :bdg-danger:`no`
   * - ``er_d_conc_bottle``
     - pmol/l
     - :bdg-danger:`no`
   * - ``tm_d_conc_bottle``
     - pmol/l
     - :bdg-danger:`no`
   * - ``yb_d_conc_bottle``
     - pmol/l
     - :bdg-danger:`no`
   * - ``lu_d_conc_bottle``
     - pmol/l
     - :bdg-danger:`no`
   * - ``user_station_number``
     - None
     - :bdg-danger:`no`
   * - ``user_sample_number``
     - None
     - :bdg-danger:`no`
   * - ``user_bottle_number``
     - None
     - :bdg-danger:`no`
   * - ``ldeo_sample_number``
     - None
     - :bdg-danger:`no`
   * - ``bnlid``
     - None
     - :bdg-danger:`no`
